import 'package:flutter/material.dart';

class DrawerItem extends StatelessWidget {

  final IconData icon;
  final String text;
  final Color splashColor, normalForegroundColor, checkedForegroundColor,
      checkedBackgroundColor;
  final Decoration backgroundDecoration;
  final ShapeBorder selectCustomBorder;
  final bool checked;
  final GestureTapCallback onTap;
  final EdgeInsetsGeometry padding;
  final FontWeight fontWeight;
  final double fontSize;

  DrawerItem({
    this.icon,
    this.text,
    this.splashColor,
    this.normalForegroundColor = const Color(0xff414141),
    this.checkedForegroundColor,
    this.checkedBackgroundColor = const Color(0x779e9e9e),
    this.backgroundDecoration,
    this.selectCustomBorder,
    this.checked = false,
    this.onTap,
    this.padding,
    this.fontWeight,
    this.fontSize,
  });

  bool get isChecked => checked ?? false;

  Color get _getNormalForegroundColor =>
      normalForegroundColor ?? Color(0xff414141);

  Color get _getCheckedForegroundColor =>
      checkedForegroundColor ?? _getNormalForegroundColor;

  Color get _getCheckedBackgroundColor =>
      checkedBackgroundColor ?? Color(0x779e9e9e);

  Decoration get _getBackgroundDecoration =>
      backgroundDecoration ?? BoxDecoration(
          color: _getCheckedBackgroundColor, borderRadius: BorderRadius.only(
        topRight: Radius.circular(100), bottomRight: Radius.circular(100),));

  ShapeBorder get _getSelectCustomBorder =>
      selectCustomBorder ?? RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
            topRight: Radius.circular(100),
            bottomRight: Radius.circular(100),));

  @override
  Widget build(BuildContext context) =>
      Container(
        decoration: isChecked ? _getBackgroundDecoration : null,
        margin: EdgeInsets.only(right: 8),
        child: InkWell(
          highlightColor: splashColor,
          splashColor: splashColor,
          customBorder: _getSelectCustomBorder,
          onTap: onTap,
          child: Padding(
            padding: padding ?? EdgeInsets.all(16),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                if(icon != null)
                  Icon(icon, color: isChecked
                      ? _getCheckedForegroundColor
                      : _getNormalForegroundColor,),
                if(icon != null) VerticalDivider(width: 24,),
                Expanded(
                  child: Text(text,
                    overflow: TextOverflow.ellipsis,
                    style: TextStyle(
                      color: isChecked
                          ? _getCheckedForegroundColor
                          : _getNormalForegroundColor,
                      fontWeight: fontWeight ?? FontWeight.normal,
                      fontSize: fontSize ?? 14.0,
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      );
}